@@ -43,10 +43,10 @@ class PyMinio:
     def remove_file(self, object_name:str) -> bool:
         try:
             self.client.remove_object(self.bucket, object_name)
-            print("Sussess")
+            #print("Sussess")
             return True
         except Exception as err:
-            print(err)
+            #print(err)
             return False
 
     def get_client(self) -> Minio:
