@@ -34,9 +34,9 @@ class KafkaReader(Reader):
             callback(message.value, handler=message, consumer=consumer)
 
 class KafkaWriter(Writer):
-    def __init__(self, *, bootstrap_servers, topic):
+    def __init__(self, *, bootstrap_servers, topic, max_request_size=1048576):
         self.topic = topic
-        self.producer = KafkaProducer(bootstrap_servers = bootstrap_servers)
+        self.producer = KafkaProducer(bootstrap_servers = bootstrap_servers, max_request_size=max_request_size)
 
     def write(self, message, *, topic=None, callback=None):
         def send_success(*args, **kwargs):
